@@ -1,5 +1,5 @@
 
-# $Id: Ebay.pm,v 2.249 2009-08-30 23:43:44 Martin Exp $
+# $Id: Ebay.pm,v 2.255 2010-08-17 21:59:25 Martin Exp $
 
 =head1 NAME
 
@@ -156,7 +156,7 @@ use WWW::SearchResult 2.072;
 use WWW::Search::Result;
 
 our
-$VERSION = do { my @r = (q$Revision: 2.249 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 2.255 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
 our $MAINTAINER = 'Martin Thurn <mthurn@cpan.org>';
 my $cgi = new CGI;
 
@@ -386,7 +386,7 @@ sub _parse_price
     # maybe just maybe we hit this because of a parsing glitch which
     # might correct itself on the next TD.
     } # if
-  if ($oTDprice->attr('class') !~ m'\b(ebcPr|prices)\b')
+  if ($oTDprice->attr('class') !~ m'\b(ebcPr|prices|prc)\b')
     {
     # If we see this, we probably were searching for Store items
     # but we ran off the bottom of the Store item list and ran
@@ -411,7 +411,7 @@ sub _parse_price
   my $currency = $self->_currency_pattern;
   my $W = $self->whitespace_pattern;
   $iPrice =~ s!($currency)$W*($currency)!$1 (Buy-It-Now for $2)!;
-  if ($iPrice =~ s/Free\s+Shipping//i)
+  if ($iPrice =~ s/FREE\s+SHIPPING//i)
     {
     $hit->shipping('free');
     } # if
@@ -508,9 +508,8 @@ sub _parse_enddate
   print STDERR " DDD   TDdate ===$s===\n" if (DEBUG_COLUMNS || (1 < $self->{_debug}));
   if (ref($oTDdate))
     {
-    if ($oTDdate->attr('class') !~ m/\b(ebcTim|time)\b/)
+    if ($oTDdate->attr('class') !~ m/\b(ebcTim|ti?me)\b/)
       {
-      print STDERR " DDD parse_enddate: oTDdate wrong class\n";
       # If we see this, we probably were searching for Buy-It-Now items
       # but we ran off the bottom of the item list and ran into the list
       # of Store items.
@@ -521,7 +520,6 @@ sub _parse_enddate
   print STDERR " DDD   raw    sDateTemp ===$sDateTemp===\n" if (DEBUG_DATES || (1 < $self->{_debug}));
   if ($sDateTemp =~ m/---/)
     {
-    print STDERR qq{ DDD parse_enddate: oTDdate is "---"\n};
     # If we see this, we probably were searching for Buy-It-Now items
     # but we ran off the bottom of the item list and ran into the list
     # of Store items.
@@ -534,6 +532,7 @@ sub _parse_enddate
   $sDateTemp =~ s!<!!;
   # Convert nbsp to regular space:
   $sDateTemp =~ s!\240!\040!g;
+  $sDateTemp =~ s!Time\s+left:!!;
   $sDateTemp = $self->_process_date_abbrevs($sDateTemp);
   print STDERR " DDD   cooked sDateTemp ===$sDateTemp===\n" if (DEBUG_DATES || (1 < $self->{_debug}));
   print STDERR " DDD   official time =====$self->{_ebay_official_time}=====\n" if (DEBUG_DATES || (1 < $self->{_debug}));
@@ -641,6 +640,10 @@ sub _get_result_count_elements
                             '_tag' => 'div',
                             class => 'pageCaptionDiv'
                            );
+  push @ao, $tree->look_down( # for BySellerID as of 2010-07
+                            '_tag' => 'div',
+                            id => 'rsc'
+                           );
   return @ao;
   } # _get_result_count_elements
 
@@ -664,6 +667,9 @@ sub _get_itemtitle_tds
   push @ao, $tree->look_down(_tag => 'td',
                              class => 'ebcTtl',
                             );
+  push @ao, $tree->look_down(_tag => 'td',
+                             class => 'dtl', # This is for eBay auctions as of 2010-07
+                            );
   # This is for BuyItNow (thanks to Brian Wilson):
   push @ao, $tree->look_down(_tag => 'td',
                              class => 'details ttl',
@@ -806,7 +812,7 @@ sub _parse_tree
     # use File::Slurp;
     # write_file('no-results.html', $self->{response}->content);
     } # unless
-  my $qrItemNum = qr{[;Q]item[=Z](\d+)[;Q]};
+  my $qrItemNum = qr{(\d{11,13})};
  TD:
   foreach my $oTDtitle (@aoTD)
     {
@@ -822,7 +828,7 @@ sub _parse_tree
     next TD if ($sTitle eq '');
     print STDERR " DDD   sTitle ===$sTitle===\n" if (1 < $self->{_debug});
     my $oURI = URI->new($oA->attr('href'));
-    next TD unless ($oURI =~ m!ViewItem!);
+    # next TD unless ($oURI =~ m!ViewItem!);
     next TD unless ($oURI =~ m!$qrItemNum!);
     my $iItemNum = $1;
     my $iCategory = -1;
@@ -1118,7 +1124,7 @@ Include parentheses so that $1 becomes the number (with commas is OK).
 
 sub _result_count_pattern
   {
-  return qr'([0-9,]+) (item|match|result)e?s? found ';
+  return qr'([0-9,]+) (item|match|result)e?s? found\b';
   } # _result_count_pattern
 
 
@@ -1151,7 +1157,7 @@ Please tell the author if you find any!
 
 =head1 AUTHOR
 
-Martin Thurn C<mthurn@cpan.org>, L<http://tinyurl.com/nn67z>.
+Martin 'Kingpin' Thurn, C<mthurn at cpan.org>, L<http://tinyurl.com/nn67z>.
 
 Some fixes along the way contributed by Troy Davis.
 
